==> endeavour_2.5.2.orig.tar.gz: endeavour-2.5.2/endeavour2/imbrtlist.h <==
/*
		 Endeavour Image Browser Thumbs List
 */

#ifndef IMBRTLIST_H
#define IMBRTLIST_H

#include <gtk/gtk.h>
#include "imbr.h"
#include "endeavour.h"


/* Selection */
extern GList *EDVImbrTListGetSelectedPaths(edv_imbr_struct *imbr);

/* Finding */
extern gint EDVImbrTListFindThumbByPath(
	edv_imbr_struct *imbr, const gchar *path
);

/* Image Loading */
extern guint8 *EDVImbrTListLoadImageRGBA(
	tlist_struct *tlist, const gchar *path,
	gint *width, gint *height, gint *bpl,
	gboolean resize_for_thumb,		/* Resize for tlist thumb */
        gboolean no_enlarge,			/* No enlarge if smaller
                                                 * than req size */
        GdkWindow *window			/* Reference window */
);

/* Realize Listing */
extern void EDVImbrTListRealizeListing(edv_imbr_struct *imbr);

/* Get Listing */
extern void EDVImbrTListGetListing(
	edv_imbr_struct *imbr, const gchar *path,
	gboolean update_status_bar
);
extern void EDVImbrTlistClear(edv_imbr_struct *imbr);

/* Thumb Image Load Iteration */
extern gint EDVImbrTListLoadIterate(
	edv_imbr_struct *imbr, gboolean update_status_bar,
	gboolean no_enlarge
);

/* Opening */
extern void EDVImbrTListOpen(
	edv_imbr_struct *imbr, gint thumb_num,
	guint state				/* Key modifiers */
);
extern void EDVImbrTListOpenWith(
	edv_imbr_struct *imbr, gint thumb_num
);

/* Renaming */
extern void EDVImbrTListDoFPromptRename(
	edv_imbr_struct *imbr, gint thumb_num
);

/* Object Callbacks */
extern void EDVImbrTListObjectAddedNotify(
	edv_imbr_struct *imbr, const gchar *path,
	const struct stat *lstat_buf
);
extern void EDVImbrTListObjectModifiedNotify(
	edv_imbr_struct *imbr, const gchar *path,
	const gchar *new_path,
	const struct stat *lstat_buf
);
extern void EDVImbrTListObjectRemovedNotify(
	edv_imbr_struct *imbr, const gchar *path
);

/* Mount Callbacks */
extern void EDVImbrTListMountNotify(
	edv_imbr_struct *imbr, edv_device_struct *dev_ptr,
	gboolean is_mounted
);


#endif	/* IMBRTLIST_H */

==> endeavour_2.5.7.orig.tar.gz: endeavour-2.5.7/endeavour2/imbrtlist.h <==
/*
		 Endeavour Image Browser Thumbs List
 */

#ifndef IMBRTLIST_H
#define IMBRTLIST_H

#include <gtk/gtk.h>
#include "imbr.h"
#include "endeavour.h"


/* Selection */
extern GList *EDVImbrTListGetSelectedPaths(edv_imbr_struct *imbr);

/* Finding */
extern gint EDVImbrTListFindThumbByPath(
	edv_imbr_struct *imbr, const gchar *path
);

/* Image Loading */
extern GList *EDVImbrTListLoadImageRGBA(
	tlist_struct *tlist, const gchar *path,
	gint *width, gint *height, gint *bpl,
	gint *nframes, GList **delay_list,
	gboolean resize_for_thumb,		/* Resize for tlist thumb */
        gboolean no_enlarge,			/* No enlarge if smaller
                                                 * than req size */
        GdkWindow *window			/* Reference window */
);

/* Realize Listing */
extern void EDVImbrTListRealizeListing(edv_imbr_struct *imbr);

/* Get Listing */
extern void EDVImbrTListGetListing(
	edv_imbr_struct *imbr, const gchar *path,
	gboolean update_status_bar
);
extern void EDVImbrTlistClear(edv_imbr_struct *imbr);

/* Thumb Image Load Iteration */
extern gint EDVImbrTListLoadIterate(
	edv_imbr_struct *imbr, gboolean update_status_bar,
	gboolean no_enlarge
);

/* Opening */
extern void EDVImbrTListOpen(
	edv_imbr_struct *imbr, gint thumb_num,
	guint state				/* Key modifiers */
);
extern void EDVImbrTListOpenWith(
	edv_imbr_struct *imbr, gint thumb_num
);

/* Renaming */
extern void EDVImbrTListDoFPromptRename(
	edv_imbr_struct *imbr, gint thumb_num
);

/* Object Callbacks */
extern void EDVImbrTListObjectAddedNotify(
	edv_imbr_struct *imbr, const gchar *path,
	const struct stat *lstat_buf
);
extern void EDVImbrTListObjectModifiedNotify(
	edv_imbr_struct *imbr, const gchar *path,
	const gchar *new_path,
	const struct stat *lstat_buf
);
extern void EDVImbrTListObjectRemovedNotify(
	edv_imbr_struct *imbr, const gchar *path
);

/* Mount Callbacks */
extern void EDVImbrTListMountNotify(
	edv_imbr_struct *imbr, edv_device_struct *dev_ptr,
	gboolean is_mounted
);


#endif	/* IMBRTLIST_H */
